"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from esv_sdk.types import BaseModel
from esv_sdk.utils import FieldMetadata, QueryParamMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class GetPassageAudioRequestTypedDict(TypedDict):
    query: str
    r"""Bible passage reference (e.g., \"John 3:16\" or \"43011016\")"""


class GetPassageAudioRequest(BaseModel):
    query: Annotated[
        str,
        pydantic.Field(alias="q"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]
    r"""Bible passage reference (e.g., \"John 3:16\" or \"43011016\")"""
